Usage
logistftest(formula=attr(data, "formula"), data=sys.parent(),
test, values, maxit = 25, maxhs=5, epsilon = .0001,
maxstep = 10, firth=TRUE, beta0)
Arguments
formula
a formula object, with the response on the left of the operator, and the
model terms on the right. The response must be a vector with 0 and 1 or FALSE and
TRUE for the model outcome, where the higher value (1 or TRUE) is modeled. It's possible
data
a data.frame where the variables named in the formula can be found, i. e.
the variables containing the binary response and the covariates.
test
righthand formula of parameters to test (e.g. ~ B +
D - 1). As default all parameter apart from the intercept are tested.
If the formula includes -1, the intercept is omitted from testing.
As alternative to the formula one can
values
null hypothesis values, default values are 0. For
testing the specific hypothesis B1=1, B4=2, B5=0 we specify test= ~
B1 + B4 + B5 - 1 and values=c(1, 2, 0).
maxit
maximum number of iterations (default value is 25)
maxhs
maximum number of step-halvings per iterations (default value is 5)
epsilon
specifies the maximum allowed change in penalized log likelihood to
declare convergence. Default value is 0.0001.
maxstep
specifies the maximum change of (standardized) parameter values allowed
in one iteration. Default value is 5.
firth
use of Firth's (1993) penalized maximum likelihood (firth=TRUE, default) or the
standard maximum likelihood method (firth=FALSE) for the logistic regression. Note
that by specifying pl=TRUE and firth=
beta0
specifies the initial values of the coefficients for the fitting algorithm.